==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridFilterDialogFilterChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { GridFilterDialogFilterChangeEventArgsDescription } from "./GridFilterDialogFilterChangeEventArgsDescription";
/**
 * @hidden
 */
export let GridFilterDialogFilterChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogFilterChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a == null) {
                GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogFilterChangeEventArgsDescriptionMetadata.c(GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a);
            ColumnFilterConditionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Filter", "ExportedType:ColumnFilterCondition");
        }
        static d(a) {
            GridFilterDialogFilterChangeEventArgsDescriptionMetadata.b(a);
            a.ad("GridFilterDialogFilterChangeEventArgs", () => new GridFilterDialogFilterChangeEventArgsDescription());
            a.ac("GridFilterDialogFilterChangeEventArgs", GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a);
        }
    }
    GridFilterDialogFilterChangeEventArgsDescriptionMetadata.$t = markType(GridFilterDialogFilterChangeEventArgsDescriptionMetadata, 'GridFilterDialogFilterChangeEventArgsDescriptionMetadata');
    GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a = null;
    return GridFilterDialogFilterChangeEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridFilterDialogFilterChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { GridFilterDialogFilterChangeEventArgsDescription } from "./GridFilterDialogFilterChangeEventArgsDescription";
/**
 * @hidden
 */
export let GridFilterDialogFilterChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogFilterChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a == null) {
                GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogFilterChangeEventArgsDescriptionMetadata.c(GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a);
            ColumnFilterConditionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Filter", "ExportedType:ColumnFilterCondition");
        }
        static d(a) {
            GridFilterDialogFilterChangeEventArgsDescriptionMetadata.b(a);
            a.ae("GridFilterDialogFilterChangeEventArgs", () => new GridFilterDialogFilterChangeEventArgsDescription());
            a.ad("GridFilterDialogFilterChangeEventArgs", GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a);
        }
    }
    GridFilterDialogFilterChangeEventArgsDescriptionMetadata.$t = markType(GridFilterDialogFilterChangeEventArgsDescriptionMetadata, 'GridFilterDialogFilterChangeEventArgsDescriptionMetadata');
    GridFilterDialogFilterChangeEventArgsDescriptionMetadata.a = null;
    return GridFilterDialogFilterChangeEventArgsDescriptionMetadata;
})();
